@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.0"
+    version = "1.8.1"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -132,6 +132,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         # payload = f"{payload} > 具体报错: {group.message} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
         payload = f"{payload} > Hi: {event.__dict__} \n\n"
+        payload = f"{payload} > Group: {group.__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
         # payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__} \n\n"
@@ -159,19 +160,19 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
                     return "{\"error\":\"参数不是数字！\"}"
 
         # 获取预设的阀值
-        counts = self.get_option("warning_counts", project)
-        if int(group.status) == 0:
-            data_1 = {
-                "msgtype": "markdown",
-                "markdown": {
-                    "title": group.title,
-                    "text": payload + '\n\n' + '@' + '@'.join(phone)
-                },
-                "at": {
-                    "atMobiles": notify_user,
-                    "isAtAll": False
-                }
-
+        # counts = self.get_option("warning_counts", project)
+        data_1 = {
+            "msgtype": "markdown",
+            "markdown": {
+                "title": group.title,
+                "text": payload + '\n\n' + '@' + '@'.join(phone)
+            },
+            "at": {
+                "atMobiles": notify_user,
+                "isAtAll": False
             }
-            for webhook_url in self.get_webhook_urls(group.project):
-                requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
+
+        }
+        for webhook_url in self.get_webhook_urls(group.project):
+            requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
+
